/************************************************************************/
/*									*/
/*	File:	ICU.h							*/
/*									*/
/*	#defines and subroutines for the interrupt controllers.		*/
/*									*/
/************************************************************************/

#ifndef	_ICU
#define	_ICU

#ifndef	_MemMap	/* This isn't necessary - it's just for efficiency */
#include "MemMap.h"
#endif

/************************************************************************/
/*									*/
/*	Function:	reset_icu					*/
/*									*/
/*	Do a cold reset of an icu.					*/
/*									*/
/*	Parameters:							*/
/*		A (struct _icu *).					*/
/*									*/
/*	Returns:							*/
/*		Nothing.						*/
/*									*/
/************************************************************************/

reset_icu(icu)
struct _icu *icu;
{
	icu->control = 0x00; /* Hard reset */
};	

/************************************************************************/
/*									*/
/*	Function:	init_icu					*/
/*									*/
/*	Initialize an icu with standard values, using the supplied 	*/
/*	input polarity and initial vector number.			*/
/*									*/
/*	Parameters:							*/
/*		A (struct _channel *), an input polarity,		*/
/*		and a vector number.					*/
/*									*/
/*	Returns:							*/
/*		Nothing.						*/
/*									*/
/************************************************************************/

init_icu(icu,polarity,vector)
struct _icu *icu;
int polarity, vector;
{
	icu->control = 0x00;	/* Reset */
	icu->control = 0x30;	/* Mask all interrupts */
	icu->control = 0x40;	/* Clear all interrupt requests */
	icu->control = 0xAC;	/* Select the auto-clear register */
	icu->data = 0x00;	/* No interrupts are auto-clear */

	if (polarity)
		icu->control = 0x90;	/* Active high inputs */
	else
		icu->control = 0x80;	/* Active low inputs */

	icu->control = 0xe0;	/* one-byte vector for interrupt #0 */
	icu->data = vector+0;
	icu->control = 0xe1;	/* one-byte vector for interrupt #1 */
	icu->data = vector+1;
	icu->control = 0xe2;	/* one-byte vector for interrupt #2 */
	icu->data = vector+2;
	icu->control = 0xe3;	/* one-byte vector for interrupt #3 */
	icu->data = vector+3;
	icu->control = 0xe4;	/* one-byte vector for interrupt #4 */
	icu->data = vector+4;
	icu->control = 0xe5;	/* one-byte vector for interrupt #5 */
	icu->data = vector+5;
	icu->control = 0xe6;	/* one-byte vector for interrupt #6 */
	icu->data = vector+6;
	icu->control = 0xe7;	/* one-byte vector for interrupt #7 */
	icu->data = vector+7;

	icu->control = 0xa1;	/* Arm the ICU */
}

/************************************************************************/
/*									*/
/*	Function:	init_icus					*/
/*									*/
/*	Initialize all three ICUs with the correct values.		*/
/*									*/
/*	Parameters:							*/
/*		None.							*/
/*									*/
/*	Returns:							*/
/*		Nothing.						*/
/*									*/
/************************************************************************/

init_icus()
{
	init_icu(ICU3,1,16);
	init_icu(ICU2,1,8);
	init_icu(ICU1,0,0);
}

#endif